==> clutk_0.2.8.orig.tar.gz: clutk-0.2.8/clutk/ctk-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "ctk-enum-types.h"
/* enumerations from "ctk-focusable.h" */
#include "ctk-focusable.h"
GType
ctk_focus_direction_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_FOCUS_DIR_NONE, "CTK_FOCUS_DIR_NONE", "none" },
        { CTK_FOCUS_DIR_NEXT, "CTK_FOCUS_DIR_NEXT", "next" },
        { CTK_FOCUS_DIR_PREV, "CTK_FOCUS_DIR_PREV", "prev" },
        { CTK_FOCUS_DIR_UP, "CTK_FOCUS_DIR_UP", "up" },
        { CTK_FOCUS_DIR_RIGHT, "CTK_FOCUS_DIR_RIGHT", "right" },
        { CTK_FOCUS_DIR_DOWN, "CTK_FOCUS_DIR_DOWN", "down" },
        { CTK_FOCUS_DIR_LEFT, "CTK_FOCUS_DIR_LEFT", "left" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkFocusDirection"), values);
    }
  return enum_type_id;
}
GType
ctk_focus_event_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_FOCUS_EVENT_NONE, "CTK_FOCUS_EVENT_NONE", "none" },
        { CTK_FOCUS_EVENT_DIRECTION, "CTK_FOCUS_EVENT_DIRECTION", "direction" },
        { CTK_FOCUS_EVENT_ACTIVATE, "CTK_FOCUS_EVENT_ACTIVATE", "activate" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkFocusEventType"), values);
    }
  return enum_type_id;
}
/* enumerations from "ctk-image.h" */
#include "ctk-image.h"
GType
ctk_image_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_IMAGE_EMPTY, "CTK_IMAGE_EMPTY", "empty" },
        { CTK_IMAGE_PIXBUF, "CTK_IMAGE_PIXBUF", "pixbuf" },
        { CTK_IMAGE_STOCK, "CTK_IMAGE_STOCK", "stock" },
        { CTK_IMAGE_ICON_NAME, "CTK_IMAGE_ICON_NAME", "icon-name" },
        { CTK_IMAGE_GICON, "CTK_IMAGE_GICON", "gicon" },
        { CTK_IMAGE_FILENAME, "CTK_IMAGE_FILENAME", "filename" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkImageType"), values);
    }
  return enum_type_id;
}
/* enumerations from "ctk-scroll-view.h" */
#include "ctk-scroll-view.h"
GType
ctk_scrollbar_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_SCROLLBAR_INSET, "CTK_SCROLLBAR_INSET", "inset" },
        { CTK_SCROLLBAR_OVERLAY, "CTK_SCROLLBAR_OVERLAY", "overlay" },
        { CTK_SCROLLBAR_HIDDEN, "CTK_SCROLLBAR_HIDDEN", "hidden" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkScrollbarType"), values);
    }
  return enum_type_id;
}
/* enumerations from "ctk-types.h" */
#include "ctk-types.h"
GType
ctk_orientation_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_ORIENTATION_HORIZONTAL, "CTK_ORIENTATION_HORIZONTAL", "horizontal" },
        { CTK_ORIENTATION_VERTICAL, "CTK_ORIENTATION_VERTICAL", "vertical" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkOrientation"), values);
    }
  return enum_type_id;
}
GType
ctk_actor_state_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_STATE_NORMAL, "CTK_STATE_NORMAL", "state-normal" },
        { CTK_STATE_ACTIVE, "CTK_STATE_ACTIVE", "state-active" },
        { CTK_STATE_PRELIGHT, "CTK_STATE_PRELIGHT", "state-prelight" },
        { CTK_STATE_SELECTED, "CTK_STATE_SELECTED", "state-selected" },
        { CTK_STATE_INSENSITIVE, "CTK_STATE_INSENSITIVE", "state-insensitive" },
        { CTK_N_STATES, "CTK_N_STATES", "n-states" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkActorState"), values);
    }
  return enum_type_id;
}

/* Generated data ends here */

==> clutk_0.3.60.orig.tar.gz: clutk-0.3.60/clutk/ctk-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "ctk-enum-types.h"
/* enumerations from "./ctk-focusable.h" */
#include "./ctk-focusable.h"
GType
ctk_focus_direction_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_FOCUS_DIR_NONE, "CTK_FOCUS_DIR_NONE", "none" },
        { CTK_FOCUS_DIR_NEXT, "CTK_FOCUS_DIR_NEXT", "next" },
        { CTK_FOCUS_DIR_PREV, "CTK_FOCUS_DIR_PREV", "prev" },
        { CTK_FOCUS_DIR_UP, "CTK_FOCUS_DIR_UP", "up" },
        { CTK_FOCUS_DIR_RIGHT, "CTK_FOCUS_DIR_RIGHT", "right" },
        { CTK_FOCUS_DIR_DOWN, "CTK_FOCUS_DIR_DOWN", "down" },
        { CTK_FOCUS_DIR_LEFT, "CTK_FOCUS_DIR_LEFT", "left" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkFocusDirection"), values);
    }
  return enum_type_id;
}
GType
ctk_focus_event_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_FOCUS_EVENT_NONE, "CTK_FOCUS_EVENT_NONE", "none" },
        { CTK_FOCUS_EVENT_DIRECTION, "CTK_FOCUS_EVENT_DIRECTION", "direction" },
        { CTK_FOCUS_EVENT_ACTIVATE, "CTK_FOCUS_EVENT_ACTIVATE", "activate" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkFocusEventType"), values);
    }
  return enum_type_id;
}
/* enumerations from "./ctk-image.h" */
#include "./ctk-image.h"
GType
ctk_image_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_IMAGE_EMPTY, "CTK_IMAGE_EMPTY", "empty" },
        { CTK_IMAGE_PIXBUF, "CTK_IMAGE_PIXBUF", "pixbuf" },
        { CTK_IMAGE_STOCK, "CTK_IMAGE_STOCK", "stock" },
        { CTK_IMAGE_ICON_NAME, "CTK_IMAGE_ICON_NAME", "icon-name" },
        { CTK_IMAGE_GICON, "CTK_IMAGE_GICON", "gicon" },
        { CTK_IMAGE_FILENAME, "CTK_IMAGE_FILENAME", "filename" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkImageType"), values);
    }
  return enum_type_id;
}
/* enumerations from "./ctk-layer.h" */
#include "./ctk-layer.h"
GType
ctk_layer_repeat_mode_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_LAYER_REPEAT_NONE, "CTK_LAYER_REPEAT_NONE", "none" },
        { CTK_LAYER_REPEAT_X, "CTK_LAYER_REPEAT_X", "x" },
        { CTK_LAYER_REPEAT_Y, "CTK_LAYER_REPEAT_Y", "y" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkLayerRepeatMode"), values);
    }
  return enum_type_id;
}
/* enumerations from "./ctk-render-target.h" */
#include "./ctk-render-target.h"
GType
ctk_render_target_flags_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GFlagsValue values[] = {
        { CTK_RENDER_TARGET_IN_USE, "CTK_RENDER_TARGET_IN_USE", "in-use" },
        { CTK_RENDER_TARGET_STACKED, "CTK_RENDER_TARGET_STACKED", "stacked" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_flags_register_static (g_intern_static_string ("CtkRenderTargetFlags"), values);
    }
  return enum_type_id;
}
/* enumerations from "./ctk-scroll-view.h" */
#include "./ctk-scroll-view.h"
GType
ctk_scrollbar_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_SCROLLBAR_INSET, "CTK_SCROLLBAR_INSET", "inset" },
        { CTK_SCROLLBAR_OVERLAY, "CTK_SCROLLBAR_OVERLAY", "overlay" },
        { CTK_SCROLLBAR_HIDDEN, "CTK_SCROLLBAR_HIDDEN", "hidden" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkScrollbarType"), values);
    }
  return enum_type_id;
}
/* enumerations from "./ctk-types.h" */
#include "./ctk-types.h"
GType
ctk_orientation_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_ORIENTATION_HORIZONTAL, "CTK_ORIENTATION_HORIZONTAL", "horizontal" },
        { CTK_ORIENTATION_VERTICAL, "CTK_ORIENTATION_VERTICAL", "vertical" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkOrientation"), values);
    }
  return enum_type_id;
}
GType
ctk_actor_state_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { CTK_STATE_NORMAL, "CTK_STATE_NORMAL", "state-normal" },
        { CTK_STATE_ACTIVE, "CTK_STATE_ACTIVE", "state-active" },
        { CTK_STATE_PRELIGHT, "CTK_STATE_PRELIGHT", "state-prelight" },
        { CTK_STATE_SELECTED, "CTK_STATE_SELECTED", "state-selected" },
        { CTK_STATE_INSENSITIVE, "CTK_STATE_INSENSITIVE", "state-insensitive" },
        { CTK_N_STATES, "CTK_N_STATES", "n-states" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("CtkActorState"), values);
    }
  return enum_type_id;
}

/* Generated data ends here */
